@@ -15,21 +15,22 @@
 #
 import abc
 from typing import Awaitable, Callable, Dict, Optional, Sequence, Union
-import pkg_resources
 
-import google.auth  # type: ignore
 import google.api_core
 from google.api_core import exceptions as core_exceptions
-from google.api_core import gapic_v1
+from google.api_core import gapic_v1, operations_v1
 from google.api_core import retry as retries
-from google.api_core import operations_v1
+import google.auth  # type: ignore
 from google.auth import credentials as ga_credentials  # type: ignore
-from google.oauth2 import service_account  # type: ignore
-
-from google.cloud.contact_center_insights_v1.types import contact_center_insights
-from google.cloud.contact_center_insights_v1.types import resources
 from google.longrunning import operations_pb2  # type: ignore
+from google.oauth2 import service_account  # type: ignore
 from google.protobuf import empty_pb2  # type: ignore
+import pkg_resources
+
+from google.cloud.contact_center_insights_v1.types import (
+    contact_center_insights,
+    resources,
+)
 
 try:
     DEFAULT_CLIENT_INFO = gapic_v1.client_info.ClientInfo(
@@ -58,6 +59,7 @@ class ContactCenterInsightsTransport(abc.ABC):
         quota_project_id: Optional[str] = None,
         client_info: gapic_v1.client_info.ClientInfo = DEFAULT_CLIENT_INFO,
         always_use_jwt_access: Optional[bool] = False,
+        api_audience: Optional[str] = None,
         **kwargs,
     ) -> None:
         """Instantiate the transport.
@@ -84,10 +86,6 @@ class ContactCenterInsightsTransport(abc.ABC):
             always_use_jwt_access (Optional[bool]): Whether self signed JWT should
                 be used for service account credentials.
         """
-        # Save the hostname. Default to port 443 (HTTPS) if none is specified.
-        if ":" not in host:
-            host += ":443"
-        self._host = host
 
         scopes_kwargs = {"scopes": scopes, "default_scopes": self.AUTH_SCOPES}
 
@@ -109,6 +107,11 @@ class ContactCenterInsightsTransport(abc.ABC):
             credentials, _ = google.auth.default(
                 **scopes_kwargs, quota_project_id=quota_project_id
             )
+            # Don't apply audience if the credentials file passed from user.
+            if hasattr(credentials, "with_gdch_audience"):
+                credentials = credentials.with_gdch_audience(
+                    api_audience if api_audience else host
+                )
 
         # If the credentials are service account credentials, then always try to use self signed JWT.
         if (
@@ -121,35 +124,58 @@ class ContactCenterInsightsTransport(abc.ABC):
         # Save the credentials.
         self._credentials = credentials
 
+        # Save the hostname. Default to port 443 (HTTPS) if none is specified.
+        if ":" not in host:
+            host += ":443"
+        self._host = host
+
     def _prep_wrapped_messages(self, client_info):
         # Precompute the wrapped methods.
         self._wrapped_methods = {
             self.create_conversation: gapic_v1.method.wrap_method(
-                self.create_conversation, default_timeout=None, client_info=client_info,
+                self.create_conversation,
+                default_timeout=None,
+                client_info=client_info,
             ),
             self.update_conversation: gapic_v1.method.wrap_method(
-                self.update_conversation, default_timeout=None, client_info=client_info,
+                self.update_conversation,
+                default_timeout=None,
+                client_info=client_info,
             ),
             self.get_conversation: gapic_v1.method.wrap_method(
-                self.get_conversation, default_timeout=None, client_info=client_info,
+                self.get_conversation,
+                default_timeout=None,
+                client_info=client_info,
             ),
             self.list_conversations: gapic_v1.method.wrap_method(
-                self.list_conversations, default_timeout=None, client_info=client_info,
+                self.list_conversations,
+                default_timeout=None,
+                client_info=client_info,
             ),
             self.delete_conversation: gapic_v1.method.wrap_method(
-                self.delete_conversation, default_timeout=None, client_info=client_info,
+                self.delete_conversation,
+                default_timeout=None,
+                client_info=client_info,
             ),
             self.create_analysis: gapic_v1.method.wrap_method(
-                self.create_analysis, default_timeout=None, client_info=client_info,
+                self.create_analysis,
+                default_timeout=None,
+                client_info=client_info,
             ),
             self.get_analysis: gapic_v1.method.wrap_method(
-                self.get_analysis, default_timeout=None, client_info=client_info,
+                self.get_analysis,
+                default_timeout=None,
+                client_info=client_info,
             ),
             self.list_analyses: gapic_v1.method.wrap_method(
-                self.list_analyses, default_timeout=None, client_info=client_info,
+                self.list_analyses,
+                default_timeout=None,
+                client_info=client_info,
             ),
             self.delete_analysis: gapic_v1.method.wrap_method(
-                self.delete_analysis, default_timeout=None, client_info=client_info,
+                self.delete_analysis,
+                default_timeout=None,
+                client_info=client_info,
             ),
             self.export_insights_data: gapic_v1.method.wrap_method(
                 self.export_insights_data,
@@ -157,22 +183,34 @@ class ContactCenterInsightsTransport(abc.ABC):
                 client_info=client_info,
             ),
             self.create_issue_model: gapic_v1.method.wrap_method(
-                self.create_issue_model, default_timeout=None, client_info=client_info,
+                self.create_issue_model,
+                default_timeout=None,
+                client_info=client_info,
             ),
             self.update_issue_model: gapic_v1.method.wrap_method(
-                self.update_issue_model, default_timeout=None, client_info=client_info,
+                self.update_issue_model,
+                default_timeout=None,
+                client_info=client_info,
             ),
             self.get_issue_model: gapic_v1.method.wrap_method(
-                self.get_issue_model, default_timeout=None, client_info=client_info,
+                self.get_issue_model,
+                default_timeout=None,
+                client_info=client_info,
             ),
             self.list_issue_models: gapic_v1.method.wrap_method(
-                self.list_issue_models, default_timeout=None, client_info=client_info,
+                self.list_issue_models,
+                default_timeout=None,
+                client_info=client_info,
             ),
             self.delete_issue_model: gapic_v1.method.wrap_method(
-                self.delete_issue_model, default_timeout=None, client_info=client_info,
+                self.delete_issue_model,
+                default_timeout=None,
+                client_info=client_info,
             ),
             self.deploy_issue_model: gapic_v1.method.wrap_method(
-                self.deploy_issue_model, default_timeout=None, client_info=client_info,
+                self.deploy_issue_model,
+                default_timeout=None,
+                client_info=client_info,
             ),
             self.undeploy_issue_model: gapic_v1.method.wrap_method(
                 self.undeploy_issue_model,
@@ -180,13 +218,19 @@ class ContactCenterInsightsTransport(abc.ABC):
                 client_info=client_info,
             ),
             self.get_issue: gapic_v1.method.wrap_method(
-                self.get_issue, default_timeout=None, client_info=client_info,
+                self.get_issue,
+                default_timeout=None,
+                client_info=client_info,
             ),
             self.list_issues: gapic_v1.method.wrap_method(
-                self.list_issues, default_timeout=None, client_info=client_info,
+                self.list_issues,
+                default_timeout=None,
+                client_info=client_info,
             ),
             self.update_issue: gapic_v1.method.wrap_method(
-                self.update_issue, default_timeout=None, client_info=client_info,
+                self.update_issue,
+                default_timeout=None,
+                client_info=client_info,
             ),
             self.calculate_issue_model_stats: gapic_v1.method.wrap_method(
                 self.calculate_issue_model_stats,
@@ -199,7 +243,9 @@ class ContactCenterInsightsTransport(abc.ABC):
                 client_info=client_info,
             ),
             self.get_phrase_matcher: gapic_v1.method.wrap_method(
-                self.get_phrase_matcher, default_timeout=None, client_info=client_info,
+                self.get_phrase_matcher,
+                default_timeout=None,
+                client_info=client_info,
             ),
             self.list_phrase_matchers: gapic_v1.method.wrap_method(
                 self.list_phrase_matchers,
@@ -217,37 +263,53 @@ class ContactCenterInsightsTransport(abc.ABC):
                 client_info=client_info,
             ),
             self.calculate_stats: gapic_v1.method.wrap_method(
-                self.calculate_stats, default_timeout=None, client_info=client_info,
+                self.calculate_stats,
+                default_timeout=None,
+                client_info=client_info,
             ),
             self.get_settings: gapic_v1.method.wrap_method(
-                self.get_settings, default_timeout=None, client_info=client_info,
+                self.get_settings,
+                default_timeout=None,
+                client_info=client_info,
             ),
             self.update_settings: gapic_v1.method.wrap_method(
-                self.update_settings, default_timeout=None, client_info=client_info,
+                self.update_settings,
+                default_timeout=None,
+                client_info=client_info,
             ),
             self.create_view: gapic_v1.method.wrap_method(
-                self.create_view, default_timeout=None, client_info=client_info,
+                self.create_view,
+                default_timeout=None,
+                client_info=client_info,
             ),
             self.get_view: gapic_v1.method.wrap_method(
-                self.get_view, default_timeout=None, client_info=client_info,
+                self.get_view,
+                default_timeout=None,
+                client_info=client_info,
             ),
             self.list_views: gapic_v1.method.wrap_method(
-                self.list_views, default_timeout=None, client_info=client_info,
+                self.list_views,
+                default_timeout=None,
+                client_info=client_info,
             ),
             self.update_view: gapic_v1.method.wrap_method(
-                self.update_view, default_timeout=None, client_info=client_info,
+                self.update_view,
+                default_timeout=None,
+                client_info=client_info,
             ),
             self.delete_view: gapic_v1.method.wrap_method(
-                self.delete_view, default_timeout=None, client_info=client_info,
+                self.delete_view,
+                default_timeout=None,
+                client_info=client_info,
             ),
         }
 
     def close(self):
         """Closes resources associated with the transport.
 
-       .. warning::
-            Only call this method if the transport is NOT shared
-            with other clients - this may cause errors in other clients!
+        .. warning::
+             Only call this method if the transport is NOT shared
+             with other clients - this may cause errors in other clients!
         """
         raise NotImplementedError()
 
@@ -586,5 +648,9 @@ class ContactCenterInsightsTransport(abc.ABC):
     ]:
         raise NotImplementedError()
 
+    @property
+    def kind(self) -> str:
+        raise NotImplementedError()
+
 
 __all__ = ("ContactCenterInsightsTransport",)
