@@ -13,14 +13,13 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 #
-import proto  # type: ignore
-
-from google.cloud.contact_center_insights_v1.types import resources
 from google.protobuf import duration_pb2  # type: ignore
 from google.protobuf import field_mask_pb2  # type: ignore
 from google.protobuf import timestamp_pb2  # type: ignore
 from google.rpc import status_pb2  # type: ignore
+import proto  # type: ignore
 
+from google.cloud.contact_center_insights_v1.types import resources
 
 __protobuf__ = proto.module(
     package="google.cloud.contactcenterinsights.v1",
@@ -101,8 +100,14 @@ class CalculateStatsRequest(proto.Message):
             properties.
     """
 
-    location = proto.Field(proto.STRING, number=1,)
-    filter = proto.Field(proto.STRING, number=2,)
+    location = proto.Field(
+        proto.STRING,
+        number=1,
+    )
+    filter = proto.Field(
+        proto.STRING,
+        number=2,
+    )
 
 
 class CalculateStatsResponse(proto.Message):
@@ -117,21 +122,21 @@ class CalculateStatsResponse(proto.Message):
             The average number of turns per conversation.
         conversation_count (int):
             The total number of conversations.
-        smart_highlighter_matches (Sequence[google.cloud.contact_center_insights_v1.types.CalculateStatsResponse.SmartHighlighterMatchesEntry]):
+        smart_highlighter_matches (Mapping[str, int]):
             A map associating each smart highlighter
             display name with its respective number of
             matches in the set of conversations.
-        custom_highlighter_matches (Sequence[google.cloud.contact_center_insights_v1.types.CalculateStatsResponse.CustomHighlighterMatchesEntry]):
+        custom_highlighter_matches (Mapping[str, int]):
             A map associating each custom highlighter
             resource name with its respective number of
             matches in the set of conversations.
-        issue_matches (Sequence[google.cloud.contact_center_insights_v1.types.CalculateStatsResponse.IssueMatchesEntry]):
+        issue_matches (Mapping[str, int]):
             A map associating each issue resource name with its
             respective number of matches in the set of conversations.
             Key has the format:
             ``projects/<Project-ID>/locations/<Location-ID>/issueModels/<Issue-Model-ID>/issues/<Issue-ID>``
             Deprecated, use ``issue_matches_stats`` field instead.
-        issue_matches_stats (Sequence[google.cloud.contact_center_insights_v1.types.CalculateStatsResponse.IssueMatchesStatsEntry]):
+        issue_matches_stats (Mapping[str, google.cloud.contact_center_insights_v1.types.IssueModelLabelStats.IssueStats]):
             A map associating each issue resource name with its
             respective number of matches in the set of conversations.
             Key has the format:
@@ -167,12 +172,19 @@ class CalculateStatsResponse(proto.Message):
             """
 
             start_time = proto.Field(
-                proto.MESSAGE, number=1, message=timestamp_pb2.Timestamp,
+                proto.MESSAGE,
+                number=1,
+                message=timestamp_pb2.Timestamp,
+            )
+            conversation_count = proto.Field(
+                proto.INT32,
+                number=2,
             )
-            conversation_count = proto.Field(proto.INT32, number=2,)
 
         interval_duration = proto.Field(
-            proto.MESSAGE, number=1, message=duration_pb2.Duration,
+            proto.MESSAGE,
+            number=1,
+            message=duration_pb2.Duration,
         )
         points = proto.RepeatedField(
             proto.MESSAGE,
@@ -181,13 +193,33 @@ class CalculateStatsResponse(proto.Message):
         )
 
     average_duration = proto.Field(
-        proto.MESSAGE, number=1, message=duration_pb2.Duration,
+        proto.MESSAGE,
+        number=1,
+        message=duration_pb2.Duration,
+    )
+    average_turn_count = proto.Field(
+        proto.INT32,
+        number=2,
+    )
+    conversation_count = proto.Field(
+        proto.INT32,
+        number=3,
+    )
+    smart_highlighter_matches = proto.MapField(
+        proto.STRING,
+        proto.INT32,
+        number=4,
+    )
+    custom_highlighter_matches = proto.MapField(
+        proto.STRING,
+        proto.INT32,
+        number=5,
+    )
+    issue_matches = proto.MapField(
+        proto.STRING,
+        proto.INT32,
+        number=6,
     )
-    average_turn_count = proto.Field(proto.INT32, number=2,)
-    conversation_count = proto.Field(proto.INT32, number=3,)
-    smart_highlighter_matches = proto.MapField(proto.STRING, proto.INT32, number=4,)
-    custom_highlighter_matches = proto.MapField(proto.STRING, proto.INT32, number=5,)
-    issue_matches = proto.MapField(proto.STRING, proto.INT32, number=6,)
     issue_matches_stats = proto.MapField(
         proto.STRING,
         proto.MESSAGE,
@@ -195,7 +227,9 @@ class CalculateStatsResponse(proto.Message):
         message=resources.IssueModelLabelStats.IssueStats,
     )
     conversation_count_time_series = proto.Field(
-        proto.MESSAGE, number=7, message=TimeSeries,
+        proto.MESSAGE,
+        number=7,
+        message=TimeSeries,
     )
 
 
@@ -214,9 +248,20 @@ class CreateAnalysisOperationMetadata(proto.Message):
             Analysis Operation belongs to.
     """
 
-    create_time = proto.Field(proto.MESSAGE, number=1, message=timestamp_pb2.Timestamp,)
-    end_time = proto.Field(proto.MESSAGE, number=2, message=timestamp_pb2.Timestamp,)
-    conversation = proto.Field(proto.STRING, number=3,)
+    create_time = proto.Field(
+        proto.MESSAGE,
+        number=1,
+        message=timestamp_pb2.Timestamp,
+    )
+    end_time = proto.Field(
+        proto.MESSAGE,
+        number=2,
+        message=timestamp_pb2.Timestamp,
+    )
+    conversation = proto.Field(
+        proto.STRING,
+        number=3,
+    )
 
 
 class CreateConversationRequest(proto.Message):
@@ -239,9 +284,19 @@ class CreateConversationRequest(proto.Message):
             are ``[a-z][0-9]-``
     """
 
-    parent = proto.Field(proto.STRING, number=1,)
-    conversation = proto.Field(proto.MESSAGE, number=2, message=resources.Conversation,)
-    conversation_id = proto.Field(proto.STRING, number=3,)
+    parent = proto.Field(
+        proto.STRING,
+        number=1,
+    )
+    conversation = proto.Field(
+        proto.MESSAGE,
+        number=2,
+        message=resources.Conversation,
+    )
+    conversation_id = proto.Field(
+        proto.STRING,
+        number=3,
+    )
 
 
 class ListConversationsRequest(proto.Message):
@@ -272,11 +327,27 @@ class ListConversationsRequest(proto.Message):
             ``BASIC``.
     """
 
-    parent = proto.Field(proto.STRING, number=1,)
-    page_size = proto.Field(proto.INT32, number=2,)
-    page_token = proto.Field(proto.STRING, number=3,)
-    filter = proto.Field(proto.STRING, number=4,)
-    view = proto.Field(proto.ENUM, number=5, enum="ConversationView",)
+    parent = proto.Field(
+        proto.STRING,
+        number=1,
+    )
+    page_size = proto.Field(
+        proto.INT32,
+        number=2,
+    )
+    page_token = proto.Field(
+        proto.STRING,
+        number=3,
+    )
+    filter = proto.Field(
+        proto.STRING,
+        number=4,
+    )
+    view = proto.Field(
+        proto.ENUM,
+        number=5,
+        enum="ConversationView",
+    )
 
 
 class ListConversationsResponse(proto.Message):
@@ -297,9 +368,14 @@ class ListConversationsResponse(proto.Message):
         return self
 
     conversations = proto.RepeatedField(
-        proto.MESSAGE, number=1, message=resources.Conversation,
+        proto.MESSAGE,
+        number=1,
+        message=resources.Conversation,
+    )
+    next_page_token = proto.Field(
+        proto.STRING,
+        number=2,
     )
-    next_page_token = proto.Field(proto.STRING, number=2,)
 
 
 class GetConversationRequest(proto.Message):
@@ -314,8 +390,15 @@ class GetConversationRequest(proto.Message):
             ``FULL``.
     """
 
-    name = proto.Field(proto.STRING, number=1,)
-    view = proto.Field(proto.ENUM, number=2, enum="ConversationView",)
+    name = proto.Field(
+        proto.STRING,
+        number=1,
+    )
+    view = proto.Field(
+        proto.ENUM,
+        number=2,
+        enum="ConversationView",
+    )
 
 
 class UpdateConversationRequest(proto.Message):
@@ -329,9 +412,15 @@ class UpdateConversationRequest(proto.Message):
             The list of fields to be updated.
     """
 
-    conversation = proto.Field(proto.MESSAGE, number=1, message=resources.Conversation,)
+    conversation = proto.Field(
+        proto.MESSAGE,
+        number=1,
+        message=resources.Conversation,
+    )
     update_mask = proto.Field(
-        proto.MESSAGE, number=2, message=field_mask_pb2.FieldMask,
+        proto.MESSAGE,
+        number=2,
+        message=field_mask_pb2.FieldMask,
     )
 
 
@@ -349,8 +438,14 @@ class DeleteConversationRequest(proto.Message):
             has no analyses.
     """
 
-    name = proto.Field(proto.STRING, number=1,)
-    force = proto.Field(proto.BOOL, number=2,)
+    name = proto.Field(
+        proto.STRING,
+        number=1,
+    )
+    force = proto.Field(
+        proto.BOOL,
+        number=2,
+    )
 
 
 class CreateAnalysisRequest(proto.Message):
@@ -364,8 +459,15 @@ class CreateAnalysisRequest(proto.Message):
             Required. The analysis to create.
     """
 
-    parent = proto.Field(proto.STRING, number=1,)
-    analysis = proto.Field(proto.MESSAGE, number=2, message=resources.Analysis,)
+    parent = proto.Field(
+        proto.STRING,
+        number=1,
+    )
+    analysis = proto.Field(
+        proto.MESSAGE,
+        number=2,
+        message=resources.Analysis,
+    )
 
 
 class ListAnalysesRequest(proto.Message):
@@ -392,10 +494,22 @@ class ListAnalysesRequest(proto.Message):
             specific properties.
     """
 
-    parent = proto.Field(proto.STRING, number=1,)
-    page_size = proto.Field(proto.INT32, number=2,)
-    page_token = proto.Field(proto.STRING, number=3,)
-    filter = proto.Field(proto.STRING, number=4,)
+    parent = proto.Field(
+        proto.STRING,
+        number=1,
+    )
+    page_size = proto.Field(
+        proto.INT32,
+        number=2,
+    )
+    page_token = proto.Field(
+        proto.STRING,
+        number=3,
+    )
+    filter = proto.Field(
+        proto.STRING,
+        number=4,
+    )
 
 
 class ListAnalysesResponse(proto.Message):
@@ -414,8 +528,15 @@ class ListAnalysesResponse(proto.Message):
     def raw_page(self):
         return self
 
-    analyses = proto.RepeatedField(proto.MESSAGE, number=1, message=resources.Analysis,)
-    next_page_token = proto.Field(proto.STRING, number=2,)
+    analyses = proto.RepeatedField(
+        proto.MESSAGE,
+        number=1,
+        message=resources.Analysis,
+    )
+    next_page_token = proto.Field(
+        proto.STRING,
+        number=2,
+    )
 
 
 class GetAnalysisRequest(proto.Message):
@@ -426,7 +547,10 @@ class GetAnalysisRequest(proto.Message):
             Required. The name of the analysis to get.
     """
 
-    name = proto.Field(proto.STRING, number=1,)
+    name = proto.Field(
+        proto.STRING,
+        number=1,
+    )
 
 
 class DeleteAnalysisRequest(proto.Message):
@@ -437,7 +561,10 @@ class DeleteAnalysisRequest(proto.Message):
             Required. The name of the analysis to delete.
     """
 
-    name = proto.Field(proto.STRING, number=1,)
+    name = proto.Field(
+        proto.STRING,
+        number=1,
+    )
 
 
 class ExportInsightsDataRequest(proto.Message):
@@ -493,17 +620,42 @@ class ExportInsightsDataRequest(proto.Message):
                 returns an INVALID_ARGUMENT error.
         """
 
-        project_id = proto.Field(proto.STRING, number=3,)
-        dataset = proto.Field(proto.STRING, number=1,)
-        table = proto.Field(proto.STRING, number=2,)
+        project_id = proto.Field(
+            proto.STRING,
+            number=3,
+        )
+        dataset = proto.Field(
+            proto.STRING,
+            number=1,
+        )
+        table = proto.Field(
+            proto.STRING,
+            number=2,
+        )
 
     big_query_destination = proto.Field(
-        proto.MESSAGE, number=2, oneof="destination", message=BigQueryDestination,
+        proto.MESSAGE,
+        number=2,
+        oneof="destination",
+        message=BigQueryDestination,
+    )
+    parent = proto.Field(
+        proto.STRING,
+        number=1,
+    )
+    filter = proto.Field(
+        proto.STRING,
+        number=3,
+    )
+    kms_key = proto.Field(
+        proto.STRING,
+        number=4,
+    )
+    write_disposition = proto.Field(
+        proto.ENUM,
+        number=5,
+        enum=WriteDisposition,
     )
-    parent = proto.Field(proto.STRING, number=1,)
-    filter = proto.Field(proto.STRING, number=3,)
-    kms_key = proto.Field(proto.STRING, number=4,)
-    write_disposition = proto.Field(proto.ENUM, number=5, enum=WriteDisposition,)
 
 
 class ExportInsightsDataMetadata(proto.Message):
@@ -524,17 +676,30 @@ class ExportInsightsDataMetadata(proto.Message):
             incomplete.
     """
 
-    create_time = proto.Field(proto.MESSAGE, number=1, message=timestamp_pb2.Timestamp,)
-    end_time = proto.Field(proto.MESSAGE, number=2, message=timestamp_pb2.Timestamp,)
-    request = proto.Field(proto.MESSAGE, number=3, message="ExportInsightsDataRequest",)
+    create_time = proto.Field(
+        proto.MESSAGE,
+        number=1,
+        message=timestamp_pb2.Timestamp,
+    )
+    end_time = proto.Field(
+        proto.MESSAGE,
+        number=2,
+        message=timestamp_pb2.Timestamp,
+    )
+    request = proto.Field(
+        proto.MESSAGE,
+        number=3,
+        message="ExportInsightsDataRequest",
+    )
     partial_errors = proto.RepeatedField(
-        proto.MESSAGE, number=4, message=status_pb2.Status,
+        proto.MESSAGE,
+        number=4,
+        message=status_pb2.Status,
     )
 
 
 class ExportInsightsDataResponse(proto.Message):
-    r"""Response for an export insights operation.
-    """
+    r"""Response for an export insights operation."""
 
 
 class CreateIssueModelRequest(proto.Message):
@@ -548,8 +713,15 @@ class CreateIssueModelRequest(proto.Message):
             Required. The issue model to create.
     """
 
-    parent = proto.Field(proto.STRING, number=1,)
-    issue_model = proto.Field(proto.MESSAGE, number=2, message=resources.IssueModel,)
+    parent = proto.Field(
+        proto.STRING,
+        number=1,
+    )
+    issue_model = proto.Field(
+        proto.MESSAGE,
+        number=2,
+        message=resources.IssueModel,
+    )
 
 
 class CreateIssueModelMetadata(proto.Message):
@@ -566,9 +738,21 @@ class CreateIssueModelMetadata(proto.Message):
             The original request for creation.
     """
 
-    create_time = proto.Field(proto.MESSAGE, number=1, message=timestamp_pb2.Timestamp,)
-    end_time = proto.Field(proto.MESSAGE, number=2, message=timestamp_pb2.Timestamp,)
-    request = proto.Field(proto.MESSAGE, number=3, message="CreateIssueModelRequest",)
+    create_time = proto.Field(
+        proto.MESSAGE,
+        number=1,
+        message=timestamp_pb2.Timestamp,
+    )
+    end_time = proto.Field(
+        proto.MESSAGE,
+        number=2,
+        message=timestamp_pb2.Timestamp,
+    )
+    request = proto.Field(
+        proto.MESSAGE,
+        number=3,
+        message="CreateIssueModelRequest",
+    )
 
 
 class UpdateIssueModelRequest(proto.Message):
@@ -581,9 +765,15 @@ class UpdateIssueModelRequest(proto.Message):
             The list of fields to be updated.
     """
 
-    issue_model = proto.Field(proto.MESSAGE, number=1, message=resources.IssueModel,)
+    issue_model = proto.Field(
+        proto.MESSAGE,
+        number=1,
+        message=resources.IssueModel,
+    )
     update_mask = proto.Field(
-        proto.MESSAGE, number=2, message=field_mask_pb2.FieldMask,
+        proto.MESSAGE,
+        number=2,
+        message=field_mask_pb2.FieldMask,
     )
 
 
@@ -596,7 +786,10 @@ class ListIssueModelsRequest(proto.Message):
             model.
     """
 
-    parent = proto.Field(proto.STRING, number=1,)
+    parent = proto.Field(
+        proto.STRING,
+        number=1,
+    )
 
 
 class ListIssueModelsResponse(proto.Message):
@@ -608,7 +801,9 @@ class ListIssueModelsResponse(proto.Message):
     """
 
     issue_models = proto.RepeatedField(
-        proto.MESSAGE, number=1, message=resources.IssueModel,
+        proto.MESSAGE,
+        number=1,
+        message=resources.IssueModel,
     )
 
 
@@ -620,7 +815,10 @@ class GetIssueModelRequest(proto.Message):
             Required. The name of the issue model to get.
     """
 
-    name = proto.Field(proto.STRING, number=1,)
+    name = proto.Field(
+        proto.STRING,
+        number=1,
+    )
 
 
 class DeleteIssueModelRequest(proto.Message):
@@ -632,7 +830,10 @@ class DeleteIssueModelRequest(proto.Message):
             delete.
     """
 
-    name = proto.Field(proto.STRING, number=1,)
+    name = proto.Field(
+        proto.STRING,
+        number=1,
+    )
 
 
 class DeleteIssueModelMetadata(proto.Message):
@@ -649,9 +850,21 @@ class DeleteIssueModelMetadata(proto.Message):
             The original request for deletion.
     """
 
-    create_time = proto.Field(proto.MESSAGE, number=1, message=timestamp_pb2.Timestamp,)
-    end_time = proto.Field(proto.MESSAGE, number=2, message=timestamp_pb2.Timestamp,)
-    request = proto.Field(proto.MESSAGE, number=3, message="DeleteIssueModelRequest",)
+    create_time = proto.Field(
+        proto.MESSAGE,
+        number=1,
+        message=timestamp_pb2.Timestamp,
+    )
+    end_time = proto.Field(
+        proto.MESSAGE,
+        number=2,
+        message=timestamp_pb2.Timestamp,
+    )
+    request = proto.Field(
+        proto.MESSAGE,
+        number=3,
+        message="DeleteIssueModelRequest",
+    )
 
 
 class DeployIssueModelRequest(proto.Message):
@@ -662,12 +875,14 @@ class DeployIssueModelRequest(proto.Message):
             Required. The issue model to deploy.
     """
 
-    name = proto.Field(proto.STRING, number=1,)
+    name = proto.Field(
+        proto.STRING,
+        number=1,
+    )
 
 
 class DeployIssueModelResponse(proto.Message):
-    r"""The response to deploy an issue model.
-    """
+    r"""The response to deploy an issue model."""
 
 
 class DeployIssueModelMetadata(proto.Message):
@@ -684,9 +899,21 @@ class DeployIssueModelMetadata(proto.Message):
             The original request for deployment.
     """
 
-    create_time = proto.Field(proto.MESSAGE, number=1, message=timestamp_pb2.Timestamp,)
-    end_time = proto.Field(proto.MESSAGE, number=2, message=timestamp_pb2.Timestamp,)
-    request = proto.Field(proto.MESSAGE, number=3, message="DeployIssueModelRequest",)
+    create_time = proto.Field(
+        proto.MESSAGE,
+        number=1,
+        message=timestamp_pb2.Timestamp,
+    )
+    end_time = proto.Field(
+        proto.MESSAGE,
+        number=2,
+        message=timestamp_pb2.Timestamp,
+    )
+    request = proto.Field(
+        proto.MESSAGE,
+        number=3,
+        message="DeployIssueModelRequest",
+    )
 
 
 class UndeployIssueModelRequest(proto.Message):
@@ -697,12 +924,14 @@ class UndeployIssueModelRequest(proto.Message):
             Required. The issue model to undeploy.
     """
 
-    name = proto.Field(proto.STRING, number=1,)
+    name = proto.Field(
+        proto.STRING,
+        number=1,
+    )
 
 
 class UndeployIssueModelResponse(proto.Message):
-    r"""The response to undeploy an issue model.
-    """
+    r"""The response to undeploy an issue model."""
 
 
 class UndeployIssueModelMetadata(proto.Message):
@@ -719,9 +948,21 @@ class UndeployIssueModelMetadata(proto.Message):
             The original request for undeployment.
     """
 
-    create_time = proto.Field(proto.MESSAGE, number=1, message=timestamp_pb2.Timestamp,)
-    end_time = proto.Field(proto.MESSAGE, number=2, message=timestamp_pb2.Timestamp,)
-    request = proto.Field(proto.MESSAGE, number=3, message="UndeployIssueModelRequest",)
+    create_time = proto.Field(
+        proto.MESSAGE,
+        number=1,
+        message=timestamp_pb2.Timestamp,
+    )
+    end_time = proto.Field(
+        proto.MESSAGE,
+        number=2,
+        message=timestamp_pb2.Timestamp,
+    )
+    request = proto.Field(
+        proto.MESSAGE,
+        number=3,
+        message="UndeployIssueModelRequest",
+    )
 
 
 class GetIssueRequest(proto.Message):
@@ -732,7 +973,10 @@ class GetIssueRequest(proto.Message):
             Required. The name of the issue to get.
     """
 
-    name = proto.Field(proto.STRING, number=1,)
+    name = proto.Field(
+        proto.STRING,
+        number=1,
+    )
 
 
 class ListIssuesRequest(proto.Message):
@@ -743,7 +987,10 @@ class ListIssuesRequest(proto.Message):
             Required. The parent resource of the issue.
     """
 
-    parent = proto.Field(proto.STRING, number=1,)
+    parent = proto.Field(
+        proto.STRING,
+        number=1,
+    )
 
 
 class ListIssuesResponse(proto.Message):
@@ -754,7 +1001,11 @@ class ListIssuesResponse(proto.Message):
             The issues that match the request.
     """
 
-    issues = proto.RepeatedField(proto.MESSAGE, number=1, message=resources.Issue,)
+    issues = proto.RepeatedField(
+        proto.MESSAGE,
+        number=1,
+        message=resources.Issue,
+    )
 
 
 class UpdateIssueRequest(proto.Message):
@@ -767,9 +1018,15 @@ class UpdateIssueRequest(proto.Message):
             The list of fields to be updated.
     """
 
-    issue = proto.Field(proto.MESSAGE, number=1, message=resources.Issue,)
+    issue = proto.Field(
+        proto.MESSAGE,
+        number=1,
+        message=resources.Issue,
+    )
     update_mask = proto.Field(
-        proto.MESSAGE, number=2, message=field_mask_pb2.FieldMask,
+        proto.MESSAGE,
+        number=2,
+        message=field_mask_pb2.FieldMask,
     )
 
 
@@ -782,7 +1039,10 @@ class CalculateIssueModelStatsRequest(proto.Message):
             model to query against.
     """
 
-    issue_model = proto.Field(proto.STRING, number=1,)
+    issue_model = proto.Field(
+        proto.STRING,
+        number=1,
+    )
 
 
 class CalculateIssueModelStatsResponse(proto.Message):
@@ -796,7 +1056,9 @@ class CalculateIssueModelStatsResponse(proto.Message):
     """
 
     current_stats = proto.Field(
-        proto.MESSAGE, number=4, message=resources.IssueModelLabelStats,
+        proto.MESSAGE,
+        number=4,
+        message=resources.IssueModelLabelStats,
     )
 
 
@@ -814,9 +1076,14 @@ class CreatePhraseMatcherRequest(proto.Message):
             create.
     """
 
-    parent = proto.Field(proto.STRING, number=1,)
+    parent = proto.Field(
+        proto.STRING,
+        number=1,
+    )
     phrase_matcher = proto.Field(
-        proto.MESSAGE, number=2, message=resources.PhraseMatcher,
+        proto.MESSAGE,
+        number=2,
+        message=resources.PhraseMatcher,
     )
 
 
@@ -845,10 +1112,22 @@ class ListPhraseMatchersRequest(proto.Message):
             specific properties.
     """
 
-    parent = proto.Field(proto.STRING, number=1,)
-    page_size = proto.Field(proto.INT32, number=2,)
-    page_token = proto.Field(proto.STRING, number=3,)
-    filter = proto.Field(proto.STRING, number=4,)
+    parent = proto.Field(
+        proto.STRING,
+        number=1,
+    )
+    page_size = proto.Field(
+        proto.INT32,
+        number=2,
+    )
+    page_token = proto.Field(
+        proto.STRING,
+        number=3,
+    )
+    filter = proto.Field(
+        proto.STRING,
+        number=4,
+    )
 
 
 class ListPhraseMatchersResponse(proto.Message):
@@ -868,9 +1147,14 @@ class ListPhraseMatchersResponse(proto.Message):
         return self
 
     phrase_matchers = proto.RepeatedField(
-        proto.MESSAGE, number=1, message=resources.PhraseMatcher,
+        proto.MESSAGE,
+        number=1,
+        message=resources.PhraseMatcher,
+    )
+    next_page_token = proto.Field(
+        proto.STRING,
+        number=2,
     )
-    next_page_token = proto.Field(proto.STRING, number=2,)
 
 
 class GetPhraseMatcherRequest(proto.Message):
@@ -882,7 +1166,10 @@ class GetPhraseMatcherRequest(proto.Message):
             get.
     """
 
-    name = proto.Field(proto.STRING, number=1,)
+    name = proto.Field(
+        proto.STRING,
+        number=1,
+    )
 
 
 class DeletePhraseMatcherRequest(proto.Message):
@@ -894,7 +1181,10 @@ class DeletePhraseMatcherRequest(proto.Message):
             delete.
     """
 
-    name = proto.Field(proto.STRING, number=1,)
+    name = proto.Field(
+        proto.STRING,
+        number=1,
+    )
 
 
 class UpdatePhraseMatcherRequest(proto.Message):
@@ -909,10 +1199,14 @@ class UpdatePhraseMatcherRequest(proto.Message):
     """
 
     phrase_matcher = proto.Field(
-        proto.MESSAGE, number=1, message=resources.PhraseMatcher,
+        proto.MESSAGE,
+        number=1,
+        message=resources.PhraseMatcher,
     )
     update_mask = proto.Field(
-        proto.MESSAGE, number=2, message=field_mask_pb2.FieldMask,
+        proto.MESSAGE,
+        number=2,
+        message=field_mask_pb2.FieldMask,
     )
 
 
@@ -925,7 +1219,10 @@ class GetSettingsRequest(proto.Message):
             to get.
     """
 
-    name = proto.Field(proto.STRING, number=1,)
+    name = proto.Field(
+        proto.STRING,
+        number=1,
+    )
 
 
 class UpdateSettingsRequest(proto.Message):
@@ -938,9 +1235,15 @@ class UpdateSettingsRequest(proto.Message):
             Required. The list of fields to be updated.
     """
 
-    settings = proto.Field(proto.MESSAGE, number=1, message=resources.Settings,)
+    settings = proto.Field(
+        proto.MESSAGE,
+        number=1,
+        message=resources.Settings,
+    )
     update_mask = proto.Field(
-        proto.MESSAGE, number=2, message=field_mask_pb2.FieldMask,
+        proto.MESSAGE,
+        number=2,
+        message=field_mask_pb2.FieldMask,
     )
 
 
@@ -957,8 +1260,15 @@ class CreateViewRequest(proto.Message):
             Required. The view resource to create.
     """
 
-    parent = proto.Field(proto.STRING, number=1,)
-    view = proto.Field(proto.MESSAGE, number=2, message=resources.View,)
+    parent = proto.Field(
+        proto.STRING,
+        number=1,
+    )
+    view = proto.Field(
+        proto.MESSAGE,
+        number=2,
+        message=resources.View,
+    )
 
 
 class GetViewRequest(proto.Message):
@@ -969,7 +1279,10 @@ class GetViewRequest(proto.Message):
             Required. The name of the view to get.
     """
 
-    name = proto.Field(proto.STRING, number=1,)
+    name = proto.Field(
+        proto.STRING,
+        number=1,
+    )
 
 
 class ListViewsRequest(proto.Message):
@@ -991,9 +1304,18 @@ class ListViewsRequest(proto.Message):
             page of data.
     """
 
-    parent = proto.Field(proto.STRING, number=1,)
-    page_size = proto.Field(proto.INT32, number=2,)
-    page_token = proto.Field(proto.STRING, number=3,)
+    parent = proto.Field(
+        proto.STRING,
+        number=1,
+    )
+    page_size = proto.Field(
+        proto.INT32,
+        number=2,
+    )
+    page_token = proto.Field(
+        proto.STRING,
+        number=3,
+    )
 
 
 class ListViewsResponse(proto.Message):
@@ -1012,8 +1334,15 @@ class ListViewsResponse(proto.Message):
     def raw_page(self):
         return self
 
-    views = proto.RepeatedField(proto.MESSAGE, number=1, message=resources.View,)
-    next_page_token = proto.Field(proto.STRING, number=2,)
+    views = proto.RepeatedField(
+        proto.MESSAGE,
+        number=1,
+        message=resources.View,
+    )
+    next_page_token = proto.Field(
+        proto.STRING,
+        number=2,
+    )
 
 
 class UpdateViewRequest(proto.Message):
@@ -1026,9 +1355,15 @@ class UpdateViewRequest(proto.Message):
             The list of fields to be updated.
     """
 
-    view = proto.Field(proto.MESSAGE, number=1, message=resources.View,)
+    view = proto.Field(
+        proto.MESSAGE,
+        number=1,
+        message=resources.View,
+    )
     update_mask = proto.Field(
-        proto.MESSAGE, number=2, message=field_mask_pb2.FieldMask,
+        proto.MESSAGE,
+        number=2,
+        message=field_mask_pb2.FieldMask,
     )
 
 
@@ -1040,7 +1375,10 @@ class DeleteViewRequest(proto.Message):
             Required. The name of the view to delete.
     """
 
-    name = proto.Field(proto.STRING, number=1,)
+    name = proto.Field(
+        proto.STRING,
+        number=1,
+    )
 
 
 __all__ = tuple(sorted(__protobuf__.manifest))
